@@ -116,7 +116,8 @@ known_schema_hashes = {
 	16: '0bcf44ca22c479b52976e5eda1de8161',
 	17: '161428ee97a00e3bf56168c3a15b7b50',
 	18: 'a0f9efcabdecfb4ddb6d8c0b69c02092',
-	19: '419e5225259c53dd36ad80d82066ff02'
+	#19: '419e5225259c53dd36ad80d82066ff02'	# 19.0 only
+	19: '9765373098b03fb208332498f34cd4b5'
 }
 
 map_schema_hash2version = {
@@ -137,7 +138,8 @@ map_schema_hash2version = {
 	'0bcf44ca22c479b52976e5eda1de8161': 16,
 	'161428ee97a00e3bf56168c3a15b7b50': 17,
 	'a0f9efcabdecfb4ddb6d8c0b69c02092': 18,
-	'419e5225259c53dd36ad80d82066ff02': 19
+	#'419e5225259c53dd36ad80d82066ff02': 19	# 19.0. only
+	'9765373098b03fb208332498f34cd4b5': 19
 }
 
 map_client_branch2required_db_version = {
@@ -182,7 +184,16 @@ order by
 
 # only works for single-column FKs but that's fine
 # needs gm-dbo, any-doc won't work
-SQL_foreign_key_name = u"""SELECT tc.constraint_schema, tc.constraint_name
+SQL_foreign_key_name = u"""SELECT
+	tc.*,
+	tc.constraint_schema,
+	tc.constraint_name,
+	tc.table_schema as source_schema,
+	tc.table_name as source_table,
+	kcu.column_name as source_column,
+	ccu.table_schema as target_schema,
+	ccu.table_name as target_table,
+	ccu.column_name as target_column
 FROM
 	information_schema.table_constraints tc
 		INNER JOIN information_schema.constraint_column_usage ccu USING (constraint_catalog, constraint_schema, constraint_name)
@@ -479,6 +490,25 @@ def set_default_login(login=None):
 	_default_dsn = dsn
 
 	return True
+
+#------------------------------------------------------------------------
+def log_auth_environment():
+	try:
+		pgpass_file = os.path.expanduser(os.path.join('~', '.pgpass'))
+		if os.path.exists(pgpass_file):
+			_log.debug('standard .pgpass (%s) exists', pgpass_file)
+		else:
+			_log.debug('standard .pgpass (%s) not found', pgpass_file)
+		pgpass_var = os.getenv('PGPASSFILE')
+		if pgpass_var is None:
+			_log.debug('$PGPASSFILE not set')
+		else:
+			if os.path.exists(pgpass_var):
+				_log.debug('$PGPASSFILE=%s exists', pgpass_var)
+			else:
+				_log.debug('$PGPASSFILE=%s not found')
+	except StandardError:
+		_log.exception('cannot detect .pgpass and or $PGPASSFILE')
 # =======================================================================
 # netadata API
 # =======================================================================
@@ -1197,9 +1227,10 @@ def run_ro_queries(link_obj=None, queries=None, verbose=False, return_data=True,
 			_log.error('query failed: [%s]', curs.query)
 			if curs.statusmessage != u'':
 				_log.error('PG status message: %s', curs.statusmessage)
+			pg_exc = make_pg_exception_fields_unicode(pg_exc)
 			_log.error('PG error code: %s', pg_exc.pgcode)
 			if pg_exc.pgerror is not None:
-				_log.error('PG error message: %s', pg_exc.pgerror.strip().strip(u'\n').strip().strip(u'\n'))
+				_log.error(u'PG error message: %s', pg_exc.u_pgerror)
 			try:
 				curs_close()
 			except dbapi.InterfaceError:
@@ -1213,9 +1244,9 @@ def run_ro_queries(link_obj=None, queries=None, verbose=False, return_data=True,
 						details
 					)
 				if pg_exc.pgerror is None:
-					msg = u'[%s]: %s' % (pg_exc.pgcode, pg_exc.pgerror)
+					msg = u'[%s]' % pg_exc.pgcode
 				else:
-					msg = u'[%s]: %s' % (pg_exc.pgcode, pg_exc.pgerror.strip().strip(u'\n').strip().strip(u'\n'))
+					msg = u'[%s]: %s' % (pg_exc.pgcode, pg_exc.u_pgerror)
 				raise gmExceptions.AccessDenied (
 					msg,
 					source = u'PostgreSQL',
@@ -1322,7 +1353,7 @@ def run_rw_queries(link_obj=None, queries=None, end_tx=False, return_data=None,
 
 	for query in queries:
 		if type(query['cmd']) is not types.UnicodeType:
-			print "run_rw_queries(): non-unicode query"
+			print "gmPG2.run_rw_queries(): non-unicode query"
 			print query['cmd']
 		try:
 			args = query['args']
@@ -1334,9 +1365,10 @@ def run_rw_queries(link_obj=None, queries=None, end_tx=False, return_data=None,
 			_log.error('RW query failed: [%s]', curs.query)
 			if curs.statusmessage != u'':
 				_log.error('PG status message: %s', curs.statusmessage)
-			_log.error('PG error code: %s', pg_exc.pgcode)
+			pg_exc = make_pg_exception_fields_unicode(pg_exc)
+			_log.error(u'PG error code: %s', pg_exc.pgcode)
 			if pg_exc.pgerror is not None:
-				_log.error('PG error message: %s', pg_exc.pgerror.strip().strip(u'\n').strip().strip(u'\n'))
+				_log.error(u'PG error message: %s', pg_exc.u_pgerror)
 			try:
 				curs_close()
 				tx_rollback()			# just for good measure
@@ -1351,9 +1383,9 @@ def run_rw_queries(link_obj=None, queries=None, end_tx=False, return_data=None,
 						details
 					)
 				if pg_exc.pgerror is None:
-					msg = u'[%s]: %s' % (pg_exc.pgcode, pg_exc.pgerror)
+					msg = u'[%s]' % pg_exc.pgcode
 				else:
-					msg = u'[%s]: %s' % (pg_exc.pgcode, pg_exc.pgerror.strip().strip(u'\n').strip().strip(u'\n'))
+					msg = u'[%s]: %s' % (pg_exc.pgcode, pg_exc.u_pgerror)
 				raise gmExceptions.AccessDenied (
 					msg,
 					source = u'PostgreSQL',
@@ -1532,7 +1564,7 @@ def get_raw_connection(dsn=None, verbose=False, readonly=True):
 		except:
 			pass
 		if verbose:
-			__log_PG_settings(curs=curs)
+			_log_PG_settings(curs=curs)
 		curs.close()
 		conn.commit()
 
@@ -1795,7 +1827,7 @@ def sanity_check_database_settings():
 
 	return 0, u''
 #------------------------------------------------------------------------
-def __log_PG_settings(curs=None):
+def _log_PG_settings(curs=None):
 	# don't use any of the run_*()s since that might
 	# create a loop if we fail here
 	# FIXME: use pg_settings
@@ -1810,8 +1842,40 @@ def __log_PG_settings(curs=None):
 		return False
 	for setting in settings:
 		_log.debug(u'PG option [%s]: %s', setting[0], setting[1])
+
+	try:
+		curs.execute(u'select pg_available_extensions()')
+	except:
+		_log.exception(u'cannot log available PG extensions')
+		return False
+	extensions = curs.fetchall()
+	if extensions is None:
+		_log.error(u'no PG extensions available')
+		return False
+	for ext in extensions:
+		_log.debug(u'PG extension: %s', ext[0])
+
 	return True
-# =======================================================================
+#========================================================================
+def make_pg_exception_fields_unicode(exc):
+
+	if not isinstance(exc, dbapi.Error):
+		return exc
+
+	if exc.pgerror is None:
+		try:
+			msg = exc.args[0]
+		except (AttributeError, IndexError, TypeError):
+			return exc
+		# assumption
+		exc.u_pgerror = unicode(msg, gmI18N.get_encoding(), 'replace')
+		return exc
+
+	# assumption
+	exc.u_pgerror = unicode(exc.pgerror, gmI18N.get_encoding(), 'replace').strip().strip(u'\n').strip().strip(u'\n')
+
+	return exc
+#------------------------------------------------------------------------
 def extract_msg_from_pg_exception(exc=None):
 
 	try:
@@ -1819,6 +1883,7 @@ def extract_msg_from_pg_exception(exc=None):
 	except (AttributeError, IndexError, TypeError):
 		return u'cannot extract message from exception'
 
+	# assumption
 	return unicode(msg, gmI18N.get_encoding(), 'replace')
 # =======================================================================
 class cAuthenticationError(dbapi.OperationalError):
