@@ -56,6 +56,14 @@ class cTopPnl(wxgTopPnl.wxgTopPnl):
 		if cfg.get(option = 'slave'):
 			self._TCTRL_patient_selector.SetEditable(0)
 			self._TCTRL_patient_selector.SetToolTip(None)
+
+		if sys.platform == u'darwin':
+			_log.debug('adjusting font size on Mac for top panel parts')
+			for ctrl in [self._TCTRL_patient_selector, self._LBL_age, self._LBL_allergies, self._TCTRL_allergies]:
+				curr_font = ctrl.GetFont()
+				mac_font = wx.FontFromNativeInfo(curr_font.NativeFontInfo)
+				mac_font.SetPointSize(pointSize = int(curr_font.GetPointSize() / 0.8))
+				ctrl.SetFont(mac_font)
 	#-------------------------------------------------------
 	def __register_interests(self):
 		# events
@@ -110,49 +118,83 @@ class cTopPnl(wxgTopPnl.wxgTopPnl):
 	#-------------------------------------------------------
 	def __update_age_label(self):
 
-		tt = _('Gender: %s (%s) - %s\n') % (
+		# no patient
+		if not self.curr_pat.connected:
+			self._LBL_age.SetLabel(_('<Age>'))
+			self._LBL_age.SetToolTipString(_('no patient selected'))
+			return
+
+		# gender is always known
+		tt = _(u'Gender: %s (%s) - %s\n') % (
 			self.curr_pat.gender_symbol,
-			self.curr_pat['gender'],
+			gmTools.coalesce(self.curr_pat[u'gender'], u'?'),
 			self.curr_pat.gender_string
 		)
+
+		# dob is not known
+		if self.curr_pat['dob'] is None:
+			age = u'%s  %s' % (
+				self.curr_pat.gender_symbol,
+				self.curr_pat.get_formatted_dob()
+			)
+			self._LBL_age.SetLabel(age)
+			self._LBL_age.SetToolTipString(tt)
+			return
+
 		tt += _('Born: %s\n') % self.curr_pat.get_formatted_dob(format = '%d %b %Y', encoding = gmI18N.get_encoding())
 
-		if self.curr_pat['deceased'] is None:
-
-			if self.curr_pat.get_formatted_dob(format = '%m-%d') == pyDT.datetime.now(tz = gmDateTime.gmCurrentLocalTimezone).strftime('%m-%d'):
-				template = _('%s  %s (%s today !)')
-				tt += _("\nToday is the patient's birtday !\n\n")
-			else:
-				template = u'%s  %s (%s)'
-
-			tt += _('Age: %s\n') % self.curr_pat['medical_age']
-
-			# FIXME: if the age is below, say, 2 hours we should fire
-			# a timer here that updates the age in increments of 1 minute ... :-)
-			age = template % (
-				gmPerson.map_gender2symbol[self.curr_pat['gender']],
-				self.curr_pat.get_formatted_dob(format = '%d %b %Y', encoding = gmI18N.get_encoding()),
-				self.curr_pat['medical_age']
-			)
-
-			# Easter Egg ;-)
-			if self.curr_pat['lastnames'] == u'Leibner':
-				if self.curr_pat['firstnames'] == u'Steffi':
-					if self.curr_pat['preferred'] == u'Wildfang':
-						age = u'%s %s' % (gmTools.u_black_heart, age)
-
-		else:
-
-			tt += _('Died: %s\n') % gmDateTime.pydt_strftime(self.curr_pat['deceased'], '%d.%b %Y')
+		# patient is dead
+		if self.curr_pat['deceased'] is not None:
+			tt += _('Died: %s\n') % gmDateTime.pydt_strftime(self.curr_pat['deceased'], '%d %b %Y')
 			tt += _('At age: %s\n') % self.curr_pat['medical_age']
-
-			template = u'%s  %s - %s (%s)'
-			age = template % (
-				gmPerson.map_gender2symbol[self.curr_pat['gender']],
-				self.curr_pat.get_formatted_dob(format = '%d.%b %Y', encoding = gmI18N.get_encoding()),
-				gmDateTime.pydt_strftime(self.curr_pat['deceased'], '%Y %b %d'),
+			age = u'%s  %s - %s (%s)' % (
+				self.curr_pat.gender_symbol,
+				self.curr_pat.get_formatted_dob(format = '%d %b %Y', encoding = gmI18N.get_encoding()),
+				gmDateTime.pydt_strftime(self.curr_pat['deceased'], '%d %b %Y'),
 				self.curr_pat['medical_age']
 			)
+			if self.curr_pat['dob_is_estimated']:
+				tt += _(' (date of birth and age are estimated)\n')
+			self._LBL_age.SetLabel(age)
+			self._LBL_age.SetToolTipString(tt)
+			return
+
+		# patient alive
+		now = gmDateTime.pydt_now_here()
+
+		# patient birthday ?
+		if self.curr_pat.get_formatted_dob(format = '%m-%d') == now.strftime('%m-%d'):
+			template = _('%(sex)s  %(dob)s (%(age)s today !)')
+			tt += _("\nToday is the patient's birtday !\n\n")
+		else:
+			if self.curr_pat.current_birthday_passed():
+				template = u'%(sex)s  %(dob)s%(l_arr)s (%(age)s)'
+				tt += _(u'Birthday: %s ago\n') % gmDateTime.format_apparent_age_medically (
+					age = gmDateTime.calculate_apparent_age(start = self.curr_pat.dob_this_year, end = now)
+				)
+			else:
+				template = u'%(sex)s  %(r_arr)s%(dob)s (%(age)s)'
+				tt += _(u'Birtday: in %s\n') % gmDateTime.format_apparent_age_medically (
+					age = gmDateTime.calculate_apparent_age(start = now, end = self.curr_pat.dob_this_year)
+				)
+
+		tt += _('Age: %s\n') % self.curr_pat['medical_age']
+
+		# FIXME: if the age is below, say, 2 hours we should fire
+		# a timer here that updates the age in increments of 1 minute ... :-)
+		age = template % {
+			u'sex': self.curr_pat.gender_symbol,
+			u'dob': self.curr_pat.get_formatted_dob(format = '%d %b %Y', encoding = gmI18N.get_encoding()),
+			u'age': self.curr_pat['medical_age'],
+			u'r_arr': gmTools.u_right_arrow,
+			u'l_arr': gmTools.u_left_arrow
+		}
+
+		# Easter Egg ;-)
+		if self.curr_pat['lastnames'] == u'Leibner':
+			if self.curr_pat['firstnames'] == u'Steffi':
+				if self.curr_pat['preferred'] == u'Wildfang':
+					age = u'%s %s' % (gmTools.u_black_heart, age)
 
 		if self.curr_pat['dob_is_estimated']:
 			tt += _(' (date of birth and age are estimated)\n')
